@@ -16,7 +16,6 @@ import os
 from mwutils.sys_stat import SystemStats
 from mwutils.logs import Logger, mili_time
 import mwutils
-% % writefile / opt/conda/lib/python3.6/site-packages/mwutils/run.py
 
 
 _STEP = 'step'
@@ -121,6 +120,7 @@ class Run():
             _data = json.load(f)
             f.close()
         if _data:
+            print(_data)
             _remote_path = _data['website']['siteUrl']
             config_user_id = _data['website']['user']['_id']
             config_lab_id = _data['website']['lab']['_id']
@@ -438,6 +438,7 @@ class Run():
                         print('Error uploading file ', file)
         if self.remote_path:
             tp = int(time.time())
+            print(prefixes)
             json_struct = {
                 "metadata": self.metadata,
                 "files": prefixes,
@@ -453,7 +454,7 @@ class Run():
                         jb = r.json()
                     except:
                         pass
-                    print("Experiment recorded.")
+                    print("resp:", r)
                     msg = "code: {}, resp.json: {}, resp.text: {}".format(
                         r.status_code, jb, r.text)
                     print(msg)
